package com.kevinsignes.animal.advisor;

import java.util.ArrayList;

import java.util.Collection;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.kevinsignes.animaladvisor.modelos.*;
import com.kevinsignes.animaladvisor.service.*;

@Component
public class AnimalAdvisorRunApp {
	@Autowired
	private AnimalService animalService;  
	@Autowired
	private AnimalQueryService animalQueryService; 
	@Autowired
	private AnimalAdvisorHelp help;
	
	

	public void run(String[] args) {
		// TODO Auto-generated method stub
		if(args.length < -1) {
			System.out.println("Error en la sintaxis");
			System.out.println(help.getHelp());
		} else if (args.length == 1){
			switch(args[0].toLowerCase()) {
				case "-l":
					animalService.mostrarTodos().forEach(System.out::println);
					break;
				default:
					System.out.println("Error en la sintaxis");
					System.out.println(help.getHelp());
			}
		} else if (args.length % 2 != 0) {
			System.out.println("Error en la sintaxis");
			System.out.println(help.getHelp());
		} else if (args.length == 0) {
			System.out.println("No se ha pasado ningún parámetro");
			System.out.println(help.getHelp());
		} else {
			List<String[]> argumentos = new ArrayList<>();
			
			for(int i = 0; i < args.length; i += 2) {
				argumentos.add(new String[] {args[i], args[i + 1]});
			}
			
			boolean error = false;
			
			for(String[] argumento : argumentos) {
				switch (argumento[0].toLowerCase()) {
				case "-bg":
					animalQueryService.buscarcolor(argumento[1]);
					break;
				case "-ba":
					animalQueryService.buscarPromedioVida(argumento[1]);
					break;
				case "-bas":
					animalQueryService.buscarDomesticos(argumento[1]);
					break;
				case "-n":
					animalQueryService.buscarHabitat(argumento[1]);
					break;
				case "-d":
					animalQueryService.buscarNombre(argumento[1]);
					break;
				case "-bp":
					animalQueryService.buscarTipo(argumento[1]);
					break;
				default: 
					error = true;
					System.out.println("Error en la sintaxis");
					System.out.println(help.getHelp());
				}
			}
			
			if (!error) {
				Collection<Animal> result = animalQueryService.ejecutar();
				System.out.printf("%s\t%s\t%s\t%s\t%s\t%s\t%s\n","ID","Nombre", "Tipo", "Habitat", "Promedio de vida", "Color", " Domestico");
				if (result != null) {
					result.forEach(vg -> System.out.printf("%s\t%s\t%s\t%s\t%s\t%s\t%s\n", 
							vg.getId(), vg.getNombre(), vg.getTipo(), 
							vg.getHabitat(), vg.getPromediaVida(), vg.getColor(), vg.getDomestico()));
				} else {
					System.out.println("No hay animales que cumplan esos criterios. Lo sentimos mucho");
				}
			}
		}
		
	}
}
