package com.kevinsignes.animaladvisor.service;

import java.util.Collection;
import java.util.function.Predicate;
import java.util.stream.Collectors;

import javax.annotation.PostConstruct;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.kevinsignes.animaladvisor.dao.*;
import com.kevinsignes.animaladvisor.modelos.*;

@Service
public class AnimalQueryServiceImpl implements AnimalQueryService {
	@Autowired
	private AnimalDao dao;
	
	private Predicate<Animal> predicate;
	
	@PostConstruct
	public void iniciar() {
		predicate = null;
	}

	@Override
	public Collection<Animal> ejecutar() {
		//@formatter:off
		return dao.mostrarTodos()
				.stream()
				.filter(predicate)
				.collect(Collectors.toList());
		//@formatter:on
	}

	@Override
	public AnimalQueryService buscarTipo(String tipo) {
		Predicate<Animal> pBuscarTipo = (ani -> ani.getTipo().substring(ani.getTipo().length()-4, ani.getTipo().length()-1).equalsIgnoreCase(tipo));
		predicate = (predicate == null) ? pBuscarTipo : predicate.and(pBuscarTipo);
		return this;
	}

	@Override
	public AnimalQueryService buscarHabitat(String habitat) {
		Predicate<Animal> pAnyo = (ani -> ani.getHabitat().substring(ani.getTipo().length()-4, ani.getTipo().length()-1).equalsIgnoreCase(habitat));
		predicate = (predicate == null) ? pAnyo : predicate.and(pAnyo);
		return this;
	}

	

	@Override
	public AnimalQueryService buscarNombre(String nombre) {
		Predicate<Animal> pNombre = (ani -> ani.getNombre().substring(ani.getNombre().length()-4, ani.getNombre().length()-1).equalsIgnoreCase(nombre));
		predicate = (predicate == null) ? pNombre : predicate.and(pNombre);
		return this;
	}
	

	@Override
	public AnimalQueryService buscarPromedioVida(String promedioVida) {
		Predicate<Animal> pPromedioVida = (ani -> ani.getPromediaVida().substring(ani.getPromediaVida().length()-4, ani.getPromediaVida().length()-1).equalsIgnoreCase(promedioVida));
		predicate = (predicate == null) ? pPromedioVida : predicate.and(pPromedioVida);
		return this;
	}

	@Override
	public AnimalQueryService buscarcolor(String color) {
		Predicate<Animal> pBuscarcolor = (ani -> ani.getColor().substring(ani.getColor().length()-4, ani.getColor().length()-1).equalsIgnoreCase(color));
		predicate = (predicate == null) ? pBuscarcolor : predicate.and(pBuscarcolor);
		return this;
	}

	@Override
	public AnimalQueryService buscarDomesticos(String domesticos) {
		Predicate<Animal> pDomesticos = (ani -> ani.getDomestico().substring(ani.getDomestico().length()-4, ani.getDomestico().length()-1).equalsIgnoreCase(domesticos));
		predicate = (predicate == null) ? pDomesticos : predicate.and(pDomesticos);
		return this;
	}

}